#[non_exhaustive]pub enum HealthStatus {
NotReady,
Ready,
Affected,
ShuttingDown,
ShutDown,
Panicked,
}Expand description
Health status returned as a part of Health.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotReady
Component is initializing and is not ready yet.
Ready
Component is ready for operations.
Affected
Component is affected by some non-fatal issue. The component is still considered healthy.
ShuttingDown
Component has received a termination request and is in the process of shutting down.
Components that shut down instantly may skip this status and proceed directly to Self::ShutDown.
ShutDown
Component is shut down.
Panicked
Component has been abnormally interrupted by a panic.
Implementations
Sourceimpl HealthStatus
impl HealthStatus
Sourcepub fn is_healthy(self) -> bool
pub fn is_healthy(self) -> bool
Checks whether a component is healthy according to this status.