This crate contains the observability subsystem. It is responsible for providing a centralized interface for consistent observability configuration.
Re-exports
pub use logs::Logs;pub use opentelemetry::OpenTelemetry;pub use sentry::Sentry;
Modules
- logs
- opentelemetry
- prometheus
- Prometheus-related functionality, such as
PrometheusExporterConfig. - sentry
Structs
- Observability
Builder - Builder for the observability subsystem. Currently capable of configuring logging output and sentry integration.
- Observability
Guard - Guard for the observability subsystem. Releases configured integrations upon being dropped.