Module wiring_layer

Module wiring_layer 

Enums

WiringError
An error that can occur during the wiring phase.

Traits

WiringLayer
Wiring layer provides a way to customize the Service by adding new tasks or resources to it.